@@ -619,3 +619,198 @@ func Test_Servers_ListApplicationsforServer_OK(t *testing.T) {
 		assert.Equal(t, "WordPress on CentOS 6 x64", apps[1].DeployName)
 	}
 }
+
+func Test_Servers_ListPrivateNetworksForServer_Error(t *testing.T) {
+	server, client := getTestServerAndClient(http.StatusNotAcceptable, `{error}`)
+	defer server.Close()
+
+	nets, err := client.ListPrivateNetworksForServer("123456789")
+	assert.Nil(t, nets)
+	if assert.NotNil(t, err) {
+		assert.Equal(t, `{error}`, err.Error())
+	}
+}
+
+func Test_Servers_ListPrivateNetworksForServer_NoOS(t *testing.T) {
+	server, client := getTestServerAndClient(http.StatusOK, `[]`)
+	defer server.Close()
+
+	nets, err := client.ListPrivateNetworksForServer("123456789")
+	if err != nil {
+		t.Error(err)
+	}
+	assert.Nil(t, nets)
+}
+
+func Test_Servers_ListPrivateNetworksForServer_OK(t *testing.T) {
+	server, client := getTestServerAndClient(http.StatusOK, `{
+"net53962b0f2341f": {"NETWORKID": "net53962b0f2341f","mac_address": "5a01.0000.24e9","ip_address": "0.0.0.0"},
+"net539626f0798d7": {"NETWORKID": "net539626f0798d7","mac_address": "5a02.0000.24e9","ip_address": "10.99.0.3"}
+}`)
+	defer server.Close()
+
+	nets, err := client.ListPrivateNetworksForServer("123456789")
+	if err != nil {
+		t.Error(err)
+	}
+	if assert.NotNil(t, nets) {
+		assert.Equal(t, 2, len(nets))
+
+		assert.Equal(t, "net53962b0f2341f", nets[0].ID)
+		assert.Equal(t, "5a01.0000.24e9", nets[0].MACAddress)
+		assert.Equal(t, "0.0.0.0", nets[0].IPAddress)
+
+		assert.Equal(t, "net539626f0798d7", nets[1].ID)
+		assert.Equal(t, "5a02.0000.24e9", nets[1].MACAddress)
+		assert.Equal(t, "10.99.0.3", nets[1].IPAddress)
+	}
+}
+
+func Test_Servers_DisablePrivateNetworkForServer_Error(t *testing.T) {
+	server, client := getTestServerAndClient(http.StatusNotAcceptable, `{error}`)
+	defer server.Close()
+
+	err := client.DisablePrivateNetworkForServer("123456789", "foo")
+	if assert.NotNil(t, err) {
+		assert.Equal(t, `{error}`, err.Error())
+	}
+}
+
+func Test_Servers_DisablePrivateNetworkForServer_OK(t *testing.T) {
+	server, client := getTestServerAndClient(http.StatusOK, `{no-response?!}`)
+	defer server.Close()
+
+	assert.Nil(t, client.DisablePrivateNetworkForServer("123456789", "foo"))
+}
+
+func Test_Servers_EnablePrivateNetworkForServer_Error(t *testing.T) {
+	server, client := getTestServerAndClient(http.StatusNotAcceptable, `{error}`)
+	defer server.Close()
+
+	err := client.EnablePrivateNetworkForServer("123456789", "foo")
+	if assert.NotNil(t, err) {
+		assert.Equal(t, `{error}`, err.Error())
+	}
+}
+
+func Test_Servers_EnablePrivateNetworkForServer_OK(t *testing.T) {
+	server, client := getTestServerAndClient(http.StatusOK, `{no-response?!}`)
+	defer server.Close()
+
+	assert.Nil(t, client.EnablePrivateNetworkForServer("123456789", "foo"))
+}
+
+func Test_Servers_BackupGetSchedule_OK(t *testing.T) {
+	server, client := getTestServerAndClient(http.StatusOK, `{
+    "enabled": true,
+    "cron_type": "weekly",
+    "next_scheduled_time_utc": "2016-05-07 08:00:00",
+    "hour": 8,
+    "dow": 6,
+    "dom": 0
+}`)
+	defer server.Close()
+
+	backupSchedule, err := client.BackupGetSchedule("123456789")
+	if err != nil {
+		t.Error(err)
+	}
+	if assert.NotNil(t, backupSchedule) {
+		assert.Equal(t, true, backupSchedule.Enabled)
+		assert.Equal(t, "weekly", backupSchedule.CronType)
+		assert.Equal(t, "2016-05-07 08:00:00", backupSchedule.NextScheduledTimeUtc)
+		assert.Equal(t, 8, backupSchedule.Hour)
+		assert.Equal(t, 6, backupSchedule.Dow)
+		assert.Equal(t, 0, backupSchedule.Dom)
+
+	}
+
+}
+
+func Test_Servers_BackupSetSchedule_OK(t *testing.T) {
+	server, client := getTestServerAndClient(http.StatusOK, `{no-response?!}`)
+	defer server.Close()
+
+	assert.Nil(t, client.BackupSetSchedule("123456789", BackupSchedule{}))
+}
+
+func Test_Servers_BackupGetSchedule_Error(t *testing.T) {
+	server, client := getTestServerAndClient(http.StatusNotAcceptable, `{error}`)
+	defer server.Close()
+
+	backupSchedule, err := client.BackupGetSchedule("123456789")
+	assert.Nil(t, backupSchedule)
+	if assert.NotNil(t, err) {
+		assert.Equal(t, `{error}`, err.Error())
+	}
+}
+
+func Test_Servers_BackupSetSchedule_Error(t *testing.T) {
+	server, client := getTestServerAndClient(http.StatusNotAcceptable, `{error}`)
+	defer server.Close()
+
+	err := client.BackupSetSchedule("123456789", BackupSchedule{})
+	if assert.NotNil(t, err) {
+		assert.Equal(t, `{error}`, err.Error())
+	}
+}
+
+func Test_Servers_ChangePlanOfServer_Error(t *testing.T) {
+	server, client := getTestServerAndClient(http.StatusNotAcceptable, `{error}`)
+	defer server.Close()
+
+	err := client.ChangePlanOfServer("123456789", 205)
+	if assert.NotNil(t, err) {
+		assert.Equal(t, `{error}`, err.Error())
+	}
+}
+
+func Test_Servers_ChangePlanOfServer_OK(t *testing.T) {
+	server, client := getTestServerAndClient(http.StatusOK, `{no-response?!}`)
+	defer server.Close()
+
+	assert.Nil(t, client.ChangePlanOfServer("123456789", 205))
+}
+
+func Test_Servers_ListUpgradePlansForServer_Error(t *testing.T) {
+	server, client := getTestServerAndClient(http.StatusNotAcceptable, `{error}`)
+	defer server.Close()
+
+	p, err := client.ListUpgradePlansForServer("123456789")
+	assert.Nil(t, p)
+	if assert.NotNil(t, err) {
+		assert.Equal(t, `{error}`, err.Error())
+	}
+}
+
+func Test_Servers_ListUpgradePlansForServer_NoPlan(t *testing.T) {
+	server, client := getTestServerAndClient(http.StatusOK, `[]`)
+	defer server.Close()
+
+	p, err := client.ListUpgradePlansForServer("123456789")
+	if err != nil {
+		t.Error(err)
+	}
+	assert.Nil(t, p)
+}
+
+func Test_Servers_ListUpgradePlansForServer_OK(t *testing.T) {
+	server, client := getTestServerAndClient(http.StatusOK, `[
+		29,
+		41,
+		61
+	]`)
+	defer server.Close()
+
+	p, err := client.ListUpgradePlansForServer("123456789")
+	if err != nil {
+		t.Error(err)
+	}
+	if assert.NotNil(t, p) {
+		assert.Equal(t, 3, len(p))
+
+		assert.Equal(t, 29, p[0])
+		assert.Equal(t, 41, p[1])
+		assert.Equal(t, 61, p[2])
+	}
+}
